pub struct PageTableRef<T, A>where
T: TableMeta,
A: FrameAllocator,{
pub root: Frame<T, A>,
}Fields
root: Frame<T, A>Implementations
Sourceimpl<T, A> PageTableRef<T, A>where
T: TableMeta,
A: FrameAllocator,
impl<T, A> PageTableRef<T, A>where
T: TableMeta,
A: FrameAllocator,
Sourcepub unsafe fn new(allocator: A) -> Result<PageTableRef<T, A>, PagingError>
pub unsafe fn new(allocator: A) -> Result<PageTableRef<T, A>, PagingError>
pub fn from_paddr(paddr: PhysAddr, allocator: A) -> PageTableRef<T, A>
Sourcepub fn map_page(
&mut self,
vaddr: VirtAddr,
paddr: PhysAddr,
page_size: usize,
config: <<T as TableMeta>::P as PageTableEntry>::PteConfig,
) -> Result<(), PagingError>
pub fn map_page( &mut self, vaddr: VirtAddr, paddr: PhysAddr, page_size: usize, config: <<T as TableMeta>::P as PageTableEntry>::PteConfig, ) -> Result<(), PagingError>
Maps one page with the requested page size.
Sourcepub fn map_region(
&mut self,
start_vaddr: VirtAddr,
get_paddr: impl Fn(VirtAddr) -> PhysAddr,
size: usize,
config: <<T as TableMeta>::P as PageTableEntry>::PteConfig,
allow_huge: bool,
) -> Result<(), PagingError>
pub fn map_region( &mut self, start_vaddr: VirtAddr, get_paddr: impl Fn(VirtAddr) -> PhysAddr, size: usize, config: <<T as TableMeta>::P as PageTableEntry>::PteConfig, allow_huge: bool, ) -> Result<(), PagingError>
Maps a contiguous virtual region, choosing large pages when possible. Mappings installed by this call are rolled back if a later page fails. TLB invalidation is deferred and batched until the region has been updated.
Sourcepub fn unmap_page(
&mut self,
vaddr: VirtAddr,
) -> Result<(PhysAddr, <<T as TableMeta>::P as PageTableEntry>::PteConfig, usize), PagingError>
pub fn unmap_page( &mut self, vaddr: VirtAddr, ) -> Result<(PhysAddr, <<T as TableMeta>::P as PageTableEntry>::PteConfig, usize), PagingError>
Unmaps one page and returns its physical address, flags, and page size.
Sourcepub fn protect_page(
&mut self,
vaddr: VirtAddr,
config: <<T as TableMeta>::P as PageTableEntry>::PteConfig,
) -> Result<usize, PagingError>
pub fn protect_page( &mut self, vaddr: VirtAddr, config: <<T as TableMeta>::P as PageTableEntry>::PteConfig, ) -> Result<usize, PagingError>
Changes one existing mapping’s flags and returns its page size.
Sourcepub fn protect_region(
&mut self,
start_vaddr: VirtAddr,
size: usize,
config: <<T as TableMeta>::P as PageTableEntry>::PteConfig,
) -> Result<(), PagingError>
pub fn protect_region( &mut self, start_vaddr: VirtAddr, size: usize, config: <<T as TableMeta>::P as PageTableEntry>::PteConfig, ) -> Result<(), PagingError>
Changes flags for a region. Unmapped base pages are skipped.
Sourcepub fn remap_page(
&mut self,
vaddr: VirtAddr,
paddr: PhysAddr,
config: <<T as TableMeta>::P as PageTableEntry>::PteConfig,
) -> Result<usize, PagingError>
pub fn remap_page( &mut self, vaddr: VirtAddr, paddr: PhysAddr, config: <<T as TableMeta>::P as PageTableEntry>::PteConfig, ) -> Result<usize, PagingError>
Remaps one existing mapping and returns its page size.
Sourcepub fn query(
&self,
vaddr: VirtAddr,
) -> Result<(PhysAddr, <<T as TableMeta>::P as PageTableEntry>::PteConfig, usize), PagingError>
pub fn query( &self, vaddr: VirtAddr, ) -> Result<(PhysAddr, <<T as TableMeta>::P as PageTableEntry>::PteConfig, usize), PagingError>
Queries one mapping and returns the translated physical address, flags, and page size.
Sourcepub fn map(
&mut self,
config: &MapConfig<<<T as TableMeta>::P as PageTableEntry>::PteConfig>,
) -> Result<(), PagingError>
pub fn map( &mut self, config: &MapConfig<<<T as TableMeta>::P as PageTableEntry>::PteConfig>, ) -> Result<(), PagingError>
映射虚拟地址范围到物理地址范围
Sourcepub fn unmap_with_config(
&mut self,
config: &UnmapConfig,
) -> Result<(), PagingError>
pub fn unmap_with_config( &mut self, config: &UnmapConfig, ) -> Result<(), PagingError>
使用配置对象取消映射
Sourcepub fn walk_all(&self, config: WalkConfig) -> PageTableWalker<'_, T, A> ⓘ
pub fn walk_all(&self, config: WalkConfig) -> PageTableWalker<'_, T, A> ⓘ
创建页表遍历迭代器
pub fn walk( &self, start_vaddr: VirtAddr, end_vaddr: VirtAddr, ) -> impl Iterator<Item = PteInfo<<T as TableMeta>::P>>
Sourcepub fn walk_valid(&self) -> impl Iterator<Item = PteInfo<<T as TableMeta>::P>>
pub fn walk_valid(&self) -> impl Iterator<Item = PteInfo<<T as TableMeta>::P>>
遍历所有有效的最终映射页表项(过滤掉无效项和中间级别的页表指针)
pub const fn page_size() -> usize
pub const fn table_levels() -> usize
pub const fn valid_bits() -> usize
Sourcepub unsafe fn destroy(self)
pub unsafe fn destroy(self)
销毁整个页表结构
此方法会:
- 递归释放根帧及所有子页表帧
- 清除所有页表项(设为invalid)
- 不释放映射的物理页(数据页/大页)
Safety
调用者必须确保:
- 没有其他代码在访问这个页表
- 没有CPU正在使用这个页表进行地址翻译
- 调用后不再使用这个PageTable实例
Sourcepub unsafe fn deallocate(&mut self)
pub unsafe fn deallocate(&mut self)
释放页表占用的所有页表帧
与destroy()不同,这个方法保留PageTable结构, 但释放所有关联的页表帧。调用后PageTable不再可用。
释放行为:
- 释放所有页表帧
- 清除所有页表项(设为invalid)
- 不释放映射的物理页(数据页/大页)
Safety
调用者必须确保:
- 没有其他代码在访问这个页表
- 没有CPU正在使用这个页表进行地址翻译
Sourcepub fn deallocate_range(
&mut self,
start_vaddr: VirtAddr,
end_vaddr: VirtAddr,
) -> Result<(), PagingError>
pub fn deallocate_range( &mut self, start_vaddr: VirtAddr, end_vaddr: VirtAddr, ) -> Result<(), PagingError>
释放页表中的指定映射区域
释放指定虚拟地址范围内的所有页表项和子页表帧 在释放前将相关PTE设为invalid
Sourcepub fn translate(
&self,
vaddr: VirtAddr,
) -> Result<(PhysAddr, <T as TableMeta>::P), PagingError>
pub fn translate( &self, vaddr: VirtAddr, ) -> Result<(PhysAddr, <T as TableMeta>::P), PagingError>
Sourcepub fn translate_with_level(
&self,
vaddr: VirtAddr,
) -> Result<(PhysAddr, <T as TableMeta>::P, usize), PagingError>
pub fn translate_with_level( &self, vaddr: VirtAddr, ) -> Result<(PhysAddr, <T as TableMeta>::P, usize), PagingError>
Translates a virtual address and returns the matched PTE level.
Sourcepub fn translate_phys(&self, vaddr: VirtAddr) -> Result<PhysAddr, PagingError>
pub fn translate_phys(&self, vaddr: VirtAddr) -> Result<PhysAddr, PagingError>
Sourcepub fn root_paddr(&self) -> PhysAddr
pub fn root_paddr(&self) -> PhysAddr
获取页表的根帧物理地址