Module timer

Module timer 

Enums

ArchTimerMode
CounterStability
Hardware counter contract exposed to the platform scheduler clock.

Functions

aarch64_timer_irq_index
aarch64_timer_mode
duration_to_ticks
Convert Duration to ticks.
elapsed
Get the elapsed time since boot.
freq
Get the timer frequency in Hz.
scheduler_clock_stability
Reports whether scheduler users may sample the raw counter on any CPU.
select_aarch64_timer_mode
set_aarch64_timer_mode
since_boot
ticks
Get the current timer tick count.
ticks_to_duration
Convert ticks to Duration.