pub fn scheduler_clock_stability() -> CounterStabilityExpand description
Reports whether scheduler users may sample the raw counter on any CPU.
pub fn scheduler_clock_stability() -> CounterStabilityReports whether scheduler users may sample the raw counter on any CPU.