Crate someboot

Crate someboot 

Modules

arch
console
frame
irq
mem
power
rtc
smp
timer

Macros

pr_range
print
println

Structs

Frame
页表帧,代表一个物理页面上的页表
MapConfig
页表映射配置
MapRecursiveConfig
内部映射递归配置
PageTable
PageTableRef
PageTableWalker
页表遍历迭代器
PhysAddr
A physical memory address.
PteInfo
页表项信息,包含原PTE对象
UnmapConfig
取消映射配置
UnmapRecursiveConfig
内部取消映射递归配置
VirtAddr
A virtual memory address.
WalkConfig
页表遍历配置

Enums

DCacheOp
PagingError

Constants

GB
KB
MB

Traits

ArchTrait
FrameAllocator
PageTableEntry
PageTableOp
TableMeta

Functions

boot_entropy
Returns the firmware-provided seed captured for this boot.
bootargs
Returns boot arguments captured from FDT, UEFI load options, or built into the image.
cmdline
fdt_addr
fdt_addr_phys
kernel_page_table_paddr
Get the current kernel page table physical address and ASID
platform_name
post_allocator
rsdp_addr_phys
set_kernel_page_table_paddr
Set the kernel page table physical address and ASID

Type Aliases

PagingResult
PteConfigOf
The opaque leaf-entry configuration used by a page-table metadata type.

Attribute Macros

entry
Attribute to declare the entry point of the program
secondary_entry
Attribute to declare the secondary entry point of the program