Module timer

Module timer 

Enums

ArchTimerMode

Functions

aarch64_timer_irq_index
aarch64_timer_mode
ack
Acknowledge and clear the timer interrupt. This must be called in the timer interrupt handler.
duration_to_ticks
Convert Duration to ticks.
elapsed
Get the elapsed time since boot.
enable
Enable the platform system timer so that timer IRQs can fire.
freq
Get the timer frequency in Hz.
irq_disable
Disable the platform system timer to stop timer IRQs.
irq_enable
irq_is_enabled
select_aarch64_timer_mode
set_aarch64_timer_mode
set_next_event
Configure the system timer with the desired interval.
set_next_event_in_ticks
since_boot
ticks
Get the current timer tick count.
ticks_to_duration
Convert ticks to Duration.