Enums
Functions
- aarch64_
timer_ irq_ index - aarch64_
timer_ mode - ack
- Acknowledge and clear the timer interrupt. This must be called in the timer interrupt handler.
- duration_
to_ ticks - Convert Duration to ticks.
- elapsed
- Get the elapsed time since boot.
- enable
- Enable the platform system timer so that timer IRQs can fire.
- freq
- Get the timer frequency in Hz.
- irq_
disable - Disable the platform system timer to stop timer IRQs.
- irq_
enable - irq_
is_ enabled - select_
aarch64_ timer_ mode - set_
aarch64_ timer_ mode - set_
next_ event - Configure the system timer with the desired interval.
- set_
next_ event_ in_ ticks - since_
boot - ticks
- Get the current timer tick count.
- ticks_
to_ duration - Convert ticks to Duration.